# vasp module

```{eval-rst}
.. automodule:: vasp
   :members:
   :undoc-members:
   :show-inheritance:
```

## Calculator

```{eval-rst}
.. autoclass:: vasp.Vasp
   :members:
   :undoc-members:
   :show-inheritance:
```

## Exceptions

```{eval-rst}
.. autoexception:: vasp.VaspException
.. autoexception:: vasp.VaspSubmitted
.. autoexception:: vasp.VaspQueued
.. autoexception:: vasp.VaspRunning
.. autoexception:: vasp.VaspNotFinished
.. autoexception:: vasp.VaspNotConverged
.. autoexception:: vasp.VaspError
```
